summaryrefslogtreecommitdiff
path: root/command.c
diff options
context:
space:
mode:
authorpommicket <pommicket@gmail.com>2023-01-03 12:25:58 -0500
committerpommicket <pommicket@gmail.com>2023-01-03 12:26:09 -0500
commit1c74c64c6429ebc3720e519cfb155b0a914e1c24 (patch)
tree75a4ccb9cfdb7e023ed19aa45b3f791d9a1dc9be /command.c
parent7428d8a59298d6a7e45cfdbfa937a770393aaa1c (diff)
different types of messages
Diffstat (limited to 'command.c')
-rw-r--r--command.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/command.c b/command.c
index cd64d38..fb9a390 100644
--- a/command.c
+++ b/command.c
@@ -516,9 +516,9 @@ void command_execute(Ted *ted, Command c, i64 argument) {
case CMD_ESCAPE:
definition_cancel_lookup(ted);
usages_cancel_lookup(ted);
- if (*ted->error_shown) {
- // dismiss error box
- *ted->error_shown = '\0';
+ if (*ted->message_shown) {
+ // dismiss message box
+ *ted->message_shown = '\0';
} else if (ted->autocomplete.open) {
autocomplete_close(ted);
} else if (ted->menu) {